lines method

dynamic lines([
  1. dynamic lines,
  2. dynamic x,
  3. dynamic y,
  4. dynamic scale,
  5. dynamic style,
  6. dynamic closed,
])

Adds series of curves (straight lines or cubic bezier curves) to canvas, starting at x, y coordinates. All data points in lines are relative to last line origin. x, y become x1,y1 for first line / curve in the set. For lines you only need to specify x2, y2 - (ending point) vector against x1, y1 starting point. For bezier curves you need to specify x2,y2,x3,y3,x4,y4 - vectors to control points 1, 2, ending point. All vectors are against the start of the curve - x1,y1.

@example .lines([2,2,-2,2,1,1,2,2,3,3,2,1], 212,110, 1,1, 'F', false) // line, line, bezier curve, line @param {Array} lines Array of vector shifts as pairs (lines) or sextets (cubic bezier curves). @param {number} x Coordinate (in units declared at inception of PDF document) against left edge of the page. @param {number} y Coordinate (in units declared at inception of PDF document) against upper edge of the page. @param {number} scale (Defaults to 1.0,1.0) x,y Scaling factor for all vectors. Elements can be any floating number Sub-one makes drawing smaller. Over-one grows the drawing. Negative flips the direction. @param {string} style A string specifying the painting style or null. Valid styles include: 'S' default - stroke, 'F' - fill, and 'DF' (or 'FD') - fill then stroke. A null value postpones setting the style so that a shape may be composed using multiple method calls. The last drawing method call used to define the shape should not have a null style argument. @param {boolean} closed If true, the path is closed with a straight line from the end of the last curve to the starting point. @function @instance @returns {jsPDF} @memberof jsPDF# @name lines

Implementation

external lines([lines, x, y, scale, style, closed]);