output method
Generates the PDF document. If type argument is undefined, output is raw body of resulting PDF returned as a string.
Implementation
external output([String? type, options]);
Generates the PDF document. If type argument is undefined, output is raw body of resulting PDF returned as a string.
external output([String? type, options]);